/* GroupMapInst.CMD - Install default group mappings for Samba */

call _LoadOtherFuncs

call _InitTempdir

call _SambaInit

/* These group mappings are obligatory */
say "Mapping Required domain groups"
address cmd samba.!netexe' groupmap add rid=512 ntgroup="Domain Admins"                unixgroup="admin"       type=domain   comment="Domain Administrators"'
address cmd samba.!netexe' groupmap add rid=513 ntgroup="Domain Users"                 unixgroup="users"       type=domain   comment="Domain Users"'
address cmd samba.!netexe' groupmap add rid=514 ntgroup="Domain Guests"                unixgroup="guests"      type=domain   comment="Domain Guests"'

/* These group mappings are optional */
say "Mapping Optional domain groups"
address cmd samba.!netexe' groupmap add rid=515 ntgroup="Domain Computers"             unixgroup="machines"    type=domain   comment="Domain Computers"'
address cmd samba.!netexe' groupmap add rid=516 ntgroup="Domain Controllers"           unixgroup="dc"          type=domain   comment="Domain Controllers"'
address cmd samba.!netexe' groupmap add rid=517 ntgroup="Domain Certificate Admins"    unixgroup="certadmin"   type=domain   comment="Domain Certificate Administrators"' 
address cmd samba.!netexe' groupmap add rid=518 ntgroup="Domain Schema Admins"         unixgroup="schemeadmin" type=domain   comment="Domain Schema Administrators"'      
address cmd samba.!netexe' groupmap add rid=519 ntgroup="Domain Enterprise Admins"     unixgroup="entadmin"    type=domain   comment="Domain Enterprise Administrators"'  
address cmd samba.!netexe' groupmap add rid=520 ntgroup="Domain Policy Admins"         unixgroup="poladmin"    type=domain   comment="Domain Policy Administrators"'      

/* The following ones are unsupported at the moment - use at your own risk */
/*
say "Mapping Builtin groups"
address cmd samba.!netexe' groupmap add rid=544 ntgroup="Builtin Admins"               unixgroup="ntadmin"   type=builtin
address cmd samba.!netexe' groupmap add rid=545 ntgroup="Builtin Users"                unixgroup="ntusers"   type=builtin
address cmd samba.!netexe' groupmap add rid=546 ntgroup="Builtin Guests"               unixgroup="ntguests"  type=builtin
address cmd samba.!netexe' groupmap add rid=547 ntgroup="Builtin Power Users"          unixgroup="" type=builtin 
address cmd samba.!netexe' groupmap add rid=548 ntgroup="Builtin Account Operators"    unixgroup="" type=builtin 
address cmd samba.!netexe' groupmap add rid=549 ntgroup="Builtin System Operators"     unixgroup="operator" type=builtin 
address cmd samba.!netexe' groupmap add rid=550 ntgroup="Builtin Print Operators"      unixgroup="lp" type=builtin 
address cmd samba.!netexe' groupmap add rid=551 ntgroup="Builtin Backup Operators"     unixgroup="backup" type=builtin 
address cmd samba.!netexe' groupmap add rid=552 ntgroup="Builtin Replicator"           unixgroup="" type=builtin 
address cmd samba.!netexe' groupmap add rid=553 ntgroup="Builtin RAS Servers"          unixgroup="" type=builtin 
 */
say "Done."
exit 0
 
_LoadOtherFuncs:
    '@echo off'

    call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
    call SysLoadFuncs

    call RxFuncAdd 'VRLoadFuncs', 'VROBJ', 'VRLoadFuncs'
    call VRLoadFuncs

/*  call rxfuncadd 'IniLoadFuncs', 'REXXINI', 'IniLoadFuncs'
    call IniLoadFuncs */
return

_InitTempDir: /* make sure we have a valid temporary directory */
    /* Get temporary directory */
    HaveNoTMPDIR  = 0
    TempDir       = translate(value('TMPDIR',,'OS2ENVIRONMENT'),'\','/')
    if TempDir = '' then do
        HaveNoTMPDIR  = 1
        TempDir = translate(value('TEMP',,'OS2ENVIRONMENT'),'\','/')
    end
    if TempDir = '' then TempDir = translate(value('TMP',,'OS2ENVIRONMENT'),'\','/')
    if TempDir = '' then TempDir = directory()
    if HaveNoTMPDIR then do
        say 'WARNING! Setting missing TMPDIR   variable to "'TempDir'".'
        ok = value('TMPDIR',TempDir,'OS2ENVIRONMENT')
    end    
    TempDir       = strip(TempDir,'T','\')||'\' /* make sure there is trailing "\" */
return

_SambaInit: /* Detect Samba components, initialize samba. stem */
    ETC      = value('ETC',,'OS2ENVIRONMENT')
    if ETC = "" then do
        say 'ETC environment variable is missing. Aborting...'
        exit -1
    end
    UnixRoot = value("UNIXROOT",,'OS2ENVIRONMENT')
    if UnixRoot = "" then do
        UnixRoot = left(ETC,length(ETC)-4)
        say 'WARNING! Setting missing UNIXROOT variable to "'UnixRoot'".'
        ok = value("UNIXROOT",UnixRoot,'OS2ENVIRONMENT')
    end
    UnixETC  = UnixRoot'\etc'

    /* find out various directories */
    parse source . . smbcmd
    samba.=''
    samba.!tools = strip(filespec('D',smbcmd)||filespec('P',smbcmd),,'\')
    smbdexe = stream(samba.!tools'\smbd.exe','c','query exists')
    if smbdexe <> "" then samba.!bin = strip(filespec('D',smbdexe)||filespec('P',smbdexe),,'\')
    smbdexe = stream(samba.!tools'\..\samba\smbd.exe','c','query exists')
    if smbdexe <> "" then samba.!bin = strip(filespec('D',smbdexe)||filespec('P',smbdexe),,'\')
    smbdexe = stream(samba.!tools'\..\smbd.exe','c','query exists')
    if smbdexe <> "" then samba.!bin = strip(filespec('D',smbdexe)||filespec('P',smbdexe),,'\')
    else do
        smbdexe = SysSearchPath("PATH","SMBD.EXE")
        if smbdexe <> "" then samba.!bin = strip(filespec('D',smbdexe)||filespec('P',smbdexe),,'\')
    end
    if samba.!bin = "" then do
        say "Cannot find smbd.exe - aborting..."
        exit -1
    end
    /* Check that smb.conf exists. */
    ok = stream(ETC'\samba\smb.conf','c','query exists')
    if ok = "" then do
        say ETC'\samba\smb.conf is missing. Aborting...'
        exit -2
    end
    else samba.!smbconf = ok
    samba.!netexe = samba.!bin||'\net.exe'
return

